require 'singleton'
require 'logger'
require 'slop'
require 'psp/toolchain'
require 'psp/toolchain/error'
require 'psp/toolchain/errors/invalid_prefix'

module PSP
  
  module Toolchain
    
    class Application
      
      include Singleton
      
      class << self
        delegate :start, to: :instance
      end
      
      attr_reader :logger, :options
      
      def initialize
        @logger = Logger.new(STDOUT)
        
        parse_options
      end
      
      def start
        
      end
      
      protected
      
      def parse_options
        options = Slop.parse strict: true, help: true, ignore_case: true do
          banner 'Usage: psp-toolchain [options]'

          on :p,  :prefix=,  'The output directory for the toolchain', required: true
          on :f,  :force,   'Force the installation of the toolchain into the -p directory'
          on :v,  :verbose, 'Enable verbosity'
        end
        
        prefix = Errors::InvalidPrefix.check(options)
        
        @options = options.to_hash.merge(prefix: prefix)
      rescue Error, Slop::Error => error
        logger.error(error.to_s)
        
        exit
      end
      
    end
    
  end
  
end
